# sklearn_fluent
Just provide x and y list and there you have it the Mathemtical function + accuracy based on the x and y list.

## You can get it at [sklearn_fluent](https://pypi.org/project/sklearn-fluent/0.0.1/)
or 
``` bash
pip install sklearn_fluent
```
